/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_yo_BJ extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] Cuba = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u025bnuk\u00f2 K\u00fab\u00e0",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u0254m\u0254 K\u00fab\u00e0",
               "",
               "\u00c0k\u00f3k\u00f2 K\u00fab\u00e0",
               "",
            };
        final String[] China = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00ccf\u025bnuk\u00f2s\u00ed Sh\u00e1\u00edn\u00e0",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u0254m\u0254 Sh\u00e1\u00edn\u00e0",
               "",
               "\u00c0k\u00f3k\u00f2 Sh\u00e1\u00edn\u00e0",
               "",
            };
        final String[] ETC_UTC = new String[] {
               "\u00c0pap\u0254\u0300 \u00c0k\u00f3k\u00f2 \u00c0gb\u00e1y\u00e9",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Atlantic = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00e0sik\u00f2 \u00c0t\u00ecl\u00e1\u0144t\u00ed\u00eck\u00ec",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ccy\u00e1l\u025bta \u00c0t\u00ecl\u00e1\u0144t\u00ed\u00eck\u00ec",
               "",
               "\u00c0k\u00f3k\u00f2 \u00c0t\u00ecl\u00e1\u0144t\u00ed\u00eck\u00ec",
               "",
            };
        final String[] Newfoundland = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u025bnuk\u00f2 Newfoundland",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u0254m\u0254 Newfoundland",
               "",
               "\u00c0k\u00f3k\u00f2 Newfoundland",
               "",
            };
        final String[] Europe_Central = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0\u00e1rin \u00e0sik\u00f2 Europe",
               "",
               "\u00c0k\u00f3k\u00f2 \u00c0\u00e1rin S\u0254m\u00e0 Europe",
               "",
               "\u00c0k\u00f3k\u00f2 \u00c0\u00e1rin Europe",
               "",
            };
        final String[] Europe_Eastern = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00e0sik\u00f2 \u00cch\u00e0 \u00ccl\u00e0 O\u00f2r\u00f9n Europe",
               "",
               "\u00c0k\u00f3k\u00f2 S\u0254m\u00e0 \u00ccha \u00ccl\u00e0 O\u00f2r\u00f9n Europe",
               "",
               "\u00c0k\u00f3k\u00f2 \u00cch\u00e0 \u00ccl\u00e0 O\u00f2r\u00f9n Europe",
               "",
            };
        final String[] Europe_Western = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00e0sik\u00f2 \u00ccw\u0254 O\u00f2r\u00f9n Europe",
               "",
               "\u00c0k\u00f3k\u00f2 S\u0254m\u00e0 \u00cch\u00e0 \u00ccw\u0254 O\u00f2r\u00f9n Europe",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ccw\u0254 O\u00f2r\u00f9n Europe",
               "",
            };
        final String[] Mexico_Pacific = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u025bnuk\u00f2 P\u00e1s\u00edf\u00ed\u00eck\u00ec M\u025b\u0301s\u00edk\u00f2",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u0254m\u0254 P\u00e1s\u00edf\u00ed\u00eck\u00ec M\u025b\u0301s\u00edk\u00f2",
               "",
               "\u00c0k\u00f3k\u00f2 P\u00e1s\u00edf\u00ed\u00eck\u00ec M\u025b\u0301sh\u00edk\u00f2",
               "",
            };
        final String[] America_Central = new String[] {
               "\u00e0k\u00f3k\u00f2 asiko \u00e0\u00e1r\u00edn gb\u00f9ngb\u00f9n",
               "",
               "Ak\u00f3k\u00f2 \u00e0\u00e1r\u00edn gb\u00f9ngb\u00f9n oj\u00fam\u0254m\u0254",
               "",
               "\u00e0k\u00f3k\u00f2 \u00e0\u00e1r\u00edn gb\u00f9ngb\u00f9n",
               "",
            };
        final String[] America_Eastern = new String[] {
               "Ak\u00f3k\u00f2 \u00c0sik\u00f2 \u00ccha \u00ccla O\u00f2r\u00f9n",
               "",
               "\u00c0k\u00f3k\u00f2 oj\u00fam\u0254m\u0254 \u00cch\u00e0 \u00ccl\u00e0 O\u00f2run",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ech\u00e0 \u00ecl\u00e0 o\u00f2r\u00f9n",
               "",
            };
        final String[] America_Pacific = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00e0sik\u00f2 P\u00e0s\u00edf\u00ed\u00eck\u00ec",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ccy\u00e1l\u025bta P\u00e0s\u00edf\u00ed\u00eck\u00ec",
               "",
               "\u00c0k\u00f3k\u00f2 P\u00e0s\u00edf\u00ed\u00eck\u00ec",
               "",
            };
        final String[] Hawaii_Aleutian = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u025bnuk\u00f2 Hawaii-Aleutian",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u0254m\u0254 Hawaii-Aleutian",
               "",
               "\u00c0k\u00f3k\u00f2 Hawaii-Aleutian",
               "",
            };
        final String[] Pierre_Miquelon = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u025bnuk\u00f2 Pierre & Miquelon",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u0254m\u0254 Pierre & Miquelon",
               "",
               "\u00c0k\u00f3k\u00f2 Pierre & Miquelon",
               "",
            };
        final String[] America_Mountain = new String[] {
               "\u00c0k\u00f3k\u00f2 asiko \u00f2k\u00e8",
               "",
               "\u00c0k\u00f3k\u00f2 oj\u00fam\u0254m\u0254 Ori-\u00f2k\u00e8",
               "",
               "\u00c0k\u00f3k\u00f2 \u00f2k\u00e8",
               "",
            };
        final String[] Mexico_Northwest = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u025bnuk\u00f2 Ap\u00e1 \u00ccw\u0254\u0300 Oor\u00f9n M\u025b\u0301sh\u00edk\u00f2",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u0254m\u0254 Ap\u00e1 \u00ccw\u0254\u0300 Oor\u00f9n M\u025b\u0301sh\u00edk\u00f2",
               "",
               "\u00c0k\u00f3k\u00f2 Ap\u00e1 \u00ccw\u0254\u0300 Oor\u00f9n M\u025b\u0301sh\u00edk\u00f2",
               "",
            };
        final String[] Greenland_Eastern = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00ccw\u0254\u0300 \u00ccf\u025bnuk\u00f2 oor\u00f9n Greenland",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ecgb\u00e0 Ooru Greenland",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ccl\u00e0 oor\u00f9n Greenland",
               "",
            };
        final String[] Greenland_Western = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u025bnuk\u00f2 \u00ccw\u0254\u0300 O\u00f2r\u00f9n Greenland",
               "",
               "\u00c0k\u00f3k\u00f2 \u00c0f\u025bnuk\u00f2 \u00ccgba O\u00f2ru Greenland",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ccw\u0254\u0300 oor\u00f9n Greenland",
               "",
            };
        final String[] Indonesia_Western = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00ccw\u0254\u0300 oor\u00f9n Indonesia",
               "",
               "",
               "",
               "",
               "",
            };
        final Object[][] data = new Object[][] {
            { "America/Los_Angeles", America_Pacific },
            { "America/Denver", America_Mountain },
            { "America/Phoenix", America_Mountain },
            { "America/Chicago", America_Central },
            { "America/New_York", America_Eastern },
            { "America/Indianapolis", America_Eastern },
            { "Pacific/Honolulu", Hawaii_Aleutian },
            { "America/Halifax", Atlantic },
            { "America/St_Johns", Newfoundland },
            { "Europe/Paris", Europe_Central },
            { "Europe/Bucharest", Europe_Eastern },
            { "Asia/Shanghai", China },
            { "UTC", ETC_UTC },
            { "ART", Europe_Eastern },
            { "CNT", Newfoundland },
            { "CST", America_Central },
            { "CTT", China },
            { "ECT", Europe_Central },
            { "PNT", America_Mountain },
            { "PRT", Atlantic },
            { "PST", America_Pacific },
            { "CST6CDT", America_Central },
            { "EST5EDT", America_Eastern },
            { "Etc/UTC", ETC_UTC },
            { "MST7MDT", America_Mountain },
            { "PST8PDT", America_Pacific },
            { "Asia/Gaza", Europe_Eastern },
            { "Asia/Amman", Europe_Eastern },
            { "Asia/Macau", China },
            { "Asia/Beirut", Europe_Eastern },
            { "Asia/Harbin", China },
            { "Asia/Hebron", Europe_Eastern },
            { "Europe/Kiev", Europe_Eastern },
            { "Europe/Oslo", Europe_Central },
            { "Europe/Riga", Europe_Eastern },
            { "Europe/Rome", Europe_Central },
            { "Africa/Cairo", Europe_Eastern },
            { "Africa/Ceuta", Europe_Central },
            { "Africa/Tunis", Europe_Central },
            { "America/Adak", Hawaii_Aleutian },
            { "Asia/Jakarta", Indonesia_Western },
            { "Asia/Nicosia", Europe_Eastern },
            { "Europe/Malta", Europe_Central },
            { "Europe/Sofia", Europe_Eastern },
            { "Europe/Vaduz", Europe_Central },
            { "SystemV/AST4", Atlantic },
            { "SystemV/CST6", America_Central },
            { "SystemV/EST5", America_Eastern },
            { "SystemV/MST7", America_Mountain },
            { "America/Aruba", Atlantic },
            { "America/Boise", America_Mountain },
            { "America/Thule", Atlantic },
            { "Asia/Damascus", Europe_Eastern },
            { "Europe/Athens", Europe_Eastern },
            { "Europe/Berlin", Europe_Central },
            { "Europe/Lisbon", Europe_Western },
            { "Europe/Madrid", Europe_Central },
            { "Europe/Monaco", Europe_Central },
            { "Europe/Prague", Europe_Central },
            { "Europe/Skopje", Europe_Central },
            { "Europe/Tirane", Europe_Central },
            { "Europe/Vienna", Europe_Central },
            { "Europe/Warsaw", Europe_Central },
            { "Europe/Zagreb", Europe_Central },
            { "Europe/Zurich", Europe_Central },
            { "SystemV/HST10", Hawaii_Aleutian },
            { "Africa/Algiers", Europe_Central },
            { "Africa/Tripoli", Europe_Eastern },
            { "America/Belize", America_Central },
            { "America/Cancun", America_Eastern },
            { "America/Cayman", America_Eastern },
            { "America/Dawson", America_Pacific },
            { "America/Havana", Cuba },
            { "America/Inuvik", America_Mountain },
            { "America/Merida", America_Central },
            { "America/Nassau", America_Eastern },
            { "America/Panama", America_Eastern },
            { "America/Regina", America_Central },
            { "Asia/Chongqing", China },
            { "Asia/Pontianak", Indonesia_Western },
            { "Europe/Andorra", Europe_Central },
            { "Europe/Tallinn", Europe_Eastern },
            { "Europe/Vatican", Europe_Central },
            { "Europe/Vilnius", Europe_Eastern },
            { "America/Antigua", Atlantic },
            { "America/Creston", America_Mountain },
            { "America/Curacao", Atlantic },
            { "America/Detroit", America_Eastern },
            { "America/Godthab", Greenland_Western },
            { "America/Grenada", Atlantic },
            { "America/Iqaluit", America_Eastern },
            { "America/Jamaica", America_Eastern },
            { "America/Managua", America_Central },
            { "America/Marigot", Atlantic },
            { "America/Moncton", Atlantic },
            { "America/Nipigon", America_Eastern },
            { "America/Ojinaga", America_Mountain },
            { "America/Tijuana", America_Pacific },
            { "America/Toronto", America_Eastern },
            { "America/Tortola", Atlantic },
            { "Atlantic/Canary", Europe_Western },
            { "Atlantic/Faeroe", Europe_Western },
            { "Europe/Belgrade", Europe_Central },
            { "Europe/Brussels", Europe_Central },
            { "Europe/Budapest", Europe_Central },
            { "Europe/Busingen", Europe_Central },
            { "Europe/Chisinau", Europe_Eastern },
            { "Europe/Helsinki", Europe_Eastern },
            { "Europe/Sarajevo", Europe_Central },
            { "Europe/Uzhgorod", Europe_Eastern },
            { "SystemV/AST4ADT", Atlantic },
            { "SystemV/CST6CDT", America_Central },
            { "SystemV/EST5EDT", America_Eastern },
            { "SystemV/MST7MDT", America_Mountain },
            { "SystemV/PST8PDT", America_Pacific },
            { "America/Anguilla", Atlantic },
            { "America/Barbados", Atlantic },
            { "America/Dominica", Atlantic },
            { "America/Edmonton", America_Mountain },
            { "America/Mazatlan", Mexico_Pacific },
            { "America/Miquelon", Pierre_Miquelon },
            { "America/Montreal", America_Eastern },
            { "America/Resolute", America_Central },
            { "America/Shiprock", America_Mountain },
            { "America/St_Kitts", Atlantic },
            { "America/St_Lucia", Atlantic },
            { "America/Winnipeg", America_Central },
            { "Atlantic/Bermuda", Atlantic },
            { "Atlantic/Madeira", Europe_Western },
            { "Europe/Amsterdam", Europe_Central },
            { "Europe/Gibraltar", Europe_Central },
            { "Europe/Ljubljana", Europe_Central },
            { "Europe/Mariehamn", Europe_Eastern },
            { "Europe/Podgorica", Europe_Central },
            { "Europe/Stockholm", Europe_Central },
            { "Pacific/Johnston", Hawaii_Aleutian },
            { "America/Chihuahua", Mexico_Pacific },
            { "America/Glace_Bay", Atlantic },
            { "America/Goose_Bay", Atlantic },
            { "America/Guatemala", America_Central },
            { "America/Matamoros", America_Central },
            { "America/Menominee", America_Central },
            { "America/Monterrey", America_Central },
            { "America/St_Thomas", Atlantic },
            { "America/Vancouver", America_Pacific },
            { "Europe/Bratislava", Europe_Central },
            { "Europe/Copenhagen", Europe_Central },
            { "Europe/Luxembourg", Europe_Central },
            { "Europe/San_Marino", Europe_Central },
            { "Europe/Zaporozhye", Europe_Eastern },
            { "America/Costa_Rica", America_Central },
            { "America/Grand_Turk", America_Eastern },
            { "America/Guadeloupe", Atlantic },
            { "America/Hermosillo", Mexico_Pacific },
            { "America/Kralendijk", Atlantic },
            { "America/Louisville", America_Eastern },
            { "America/Martinique", Atlantic },
            { "America/Montserrat", Atlantic },
            { "America/St_Vincent", Atlantic },
            { "America/Whitehorse", America_Pacific },
            { "Atlantic/Jan_Mayen", Europe_Central },
            { "Europe/Kaliningrad", Europe_Eastern },
            { "America/El_Salvador", America_Central },
            { "America/Fort_Nelson", America_Mountain },
            { "America/Mexico_City", America_Central },
            { "America/Pangnirtung", America_Eastern },
            { "America/Puerto_Rico", Atlantic },
            { "America/Rainy_River", America_Central },
            { "America/Tegucigalpa", America_Central },
            { "America/Thunder_Bay", America_Eastern },
            { "America/Yellowknife", America_Mountain },
            { "Arctic/Longyearbyen", Europe_Central },
            { "America/Blanc-Sablon", Atlantic },
            { "America/Dawson_Creek", America_Mountain },
            { "America/Indiana/Knox", America_Central },
            { "America/Rankin_Inlet", America_Central },
            { "America/Santa_Isabel", Mexico_Northwest },
            { "America/Scoresbysund", Greenland_Eastern },
            { "America/Cambridge_Bay", America_Mountain },
            { "America/Coral_Harbour", America_Eastern },
            { "America/Indiana/Vevay", America_Eastern },
            { "America/Lower_Princes", Atlantic },
            { "America/Port_of_Spain", Atlantic },
            { "America/Santo_Domingo", Atlantic },
            { "America/St_Barthelemy", Atlantic },
            { "America/Swift_Current", America_Central },
            { "America/Bahia_Banderas", America_Central },
            { "America/Port-au-Prince", America_Eastern },
            { "America/Indiana/Marengo", America_Eastern },
            { "America/Indiana/Winamac", America_Eastern },
            { "America/Indiana/Tell_City", America_Central },
            { "America/Indiana/Vincennes", America_Eastern },
            { "America/Indiana/Petersburg", America_Eastern },
            { "America/Kentucky/Monticello", America_Eastern },
            { "America/North_Dakota/Beulah", America_Central },
            { "America/North_Dakota/Center", America_Central },
            { "timezone.excity.Etc/Unknown", "\u00ccl\u00fa \u00c0\u00ecm\u0254\u0300" },
            { "America/North_Dakota/New_Salem", America_Central },
        };
        return data;
    }
}
